# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TimeTrackingEntryBase(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'duration_minutes': 'int',
        'entered_on': 'date',
        'created_by': 'StoryResponseAssignee',
        'task': 'StoryResponseTask',
        'created_at': 'datetime'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'duration_minutes': 'duration_minutes',
        'entered_on': 'entered_on',
        'created_by': 'created_by',
        'task': 'task',
        'created_at': 'created_at'
    }

    def __init__(self, gid=None, resource_type=None, duration_minutes=None, entered_on=None, created_by=None, task=None, created_at=None):  # noqa: E501
        """TimeTrackingEntryBase - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._duration_minutes = None
        self._entered_on = None
        self._created_by = None
        self._task = None
        self._created_at = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if duration_minutes is not None:
            self.duration_minutes = duration_minutes
        if entered_on is not None:
            self.entered_on = entered_on
        if created_by is not None:
            self.created_by = created_by
        if task is not None:
            self.task = task
        if created_at is not None:
            self.created_at = created_at

    @property
    def gid(self):
        """Gets the gid of this TimeTrackingEntryBase.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this TimeTrackingEntryBase.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this TimeTrackingEntryBase.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this TimeTrackingEntryBase.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this TimeTrackingEntryBase.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this TimeTrackingEntryBase.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this TimeTrackingEntryBase.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this TimeTrackingEntryBase.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def duration_minutes(self):
        """Gets the duration_minutes of this TimeTrackingEntryBase.  # noqa: E501

        Time in minutes tracked by the entry.  # noqa: E501

        :return: The duration_minutes of this TimeTrackingEntryBase.  # noqa: E501
        :rtype: int
        """
        return self._duration_minutes

    @duration_minutes.setter
    def duration_minutes(self, duration_minutes):
        """Sets the duration_minutes of this TimeTrackingEntryBase.

        Time in minutes tracked by the entry.  # noqa: E501

        :param duration_minutes: The duration_minutes of this TimeTrackingEntryBase.  # noqa: E501
        :type: int
        """

        self._duration_minutes = duration_minutes

    @property
    def entered_on(self):
        """Gets the entered_on of this TimeTrackingEntryBase.  # noqa: E501

        The day that this entry is logged on.  # noqa: E501

        :return: The entered_on of this TimeTrackingEntryBase.  # noqa: E501
        :rtype: date
        """
        return self._entered_on

    @entered_on.setter
    def entered_on(self, entered_on):
        """Sets the entered_on of this TimeTrackingEntryBase.

        The day that this entry is logged on.  # noqa: E501

        :param entered_on: The entered_on of this TimeTrackingEntryBase.  # noqa: E501
        :type: date
        """

        self._entered_on = entered_on

    @property
    def created_by(self):
        """Gets the created_by of this TimeTrackingEntryBase.  # noqa: E501


        :return: The created_by of this TimeTrackingEntryBase.  # noqa: E501
        :rtype: StoryResponseAssignee
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this TimeTrackingEntryBase.


        :param created_by: The created_by of this TimeTrackingEntryBase.  # noqa: E501
        :type: StoryResponseAssignee
        """

        self._created_by = created_by

    @property
    def task(self):
        """Gets the task of this TimeTrackingEntryBase.  # noqa: E501


        :return: The task of this TimeTrackingEntryBase.  # noqa: E501
        :rtype: StoryResponseTask
        """
        return self._task

    @task.setter
    def task(self, task):
        """Sets the task of this TimeTrackingEntryBase.


        :param task: The task of this TimeTrackingEntryBase.  # noqa: E501
        :type: StoryResponseTask
        """

        self._task = task

    @property
    def created_at(self):
        """Gets the created_at of this TimeTrackingEntryBase.  # noqa: E501

        The time at which this resource was created.  # noqa: E501

        :return: The created_at of this TimeTrackingEntryBase.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this TimeTrackingEntryBase.

        The time at which this resource was created.  # noqa: E501

        :param created_at: The created_at of this TimeTrackingEntryBase.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TimeTrackingEntryBase, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimeTrackingEntryBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.api.tags_api import TagsApi  # noqa: E501
from asana.rest import ApiException


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    def setUp(self):
        self.api = TagsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_tag(self):
        """Test case for create_tag

        Create a tag  # noqa: E501
        """
        pass

    def test_create_tag_for_workspace(self):
        """Test case for create_tag_for_workspace

        Create a tag in a workspace  # noqa: E501
        """
        pass

    def test_delete_tag(self):
        """Test case for delete_tag

        Delete a tag  # noqa: E501
        """
        pass

    def test_get_tag(self):
        """Test case for get_tag

        Get a tag  # noqa: E501
        """
        pass

    def test_get_tags(self):
        """Test case for get_tags

        Get multiple tags  # noqa: E501
        """
        pass

    def test_get_tags_for_task(self):
        """Test case for get_tags_for_task

        Get a task's tags  # noqa: E501
        """
        pass

    def test_get_tags_for_workspace(self):
        """Test case for get_tags_for_workspace

        Get tags in a workspace  # noqa: E501
        """
        pass

    def test_update_tag(self):
        """Test case for update_tag

        Update a tag  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PortfolioResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'name': 'str',
        'color': 'str',
        'created_at': 'datetime',
        'created_by': 'CustomFieldResponsePeopleValue',
        'custom_field_settings': 'list[PortfolioResponseCustomFieldSettings]',
        'current_status_update': 'PortfolioResponseCurrentStatusUpdate',
        'due_on': 'date',
        'custom_fields': 'list[PortfolioResponseCustomFields]',
        'members': 'list[CustomFieldResponsePeopleValue]',
        'owner': 'CustomFieldResponsePeopleValue',
        'start_on': 'date',
        'workspace': 'PortfolioResponseWorkspace',
        'permalink_url': 'str',
        'public': 'bool',
        'project_templates': 'list[JobBaseNewProjectTemplate]'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'name': 'name',
        'color': 'color',
        'created_at': 'created_at',
        'created_by': 'created_by',
        'custom_field_settings': 'custom_field_settings',
        'current_status_update': 'current_status_update',
        'due_on': 'due_on',
        'custom_fields': 'custom_fields',
        'members': 'members',
        'owner': 'owner',
        'start_on': 'start_on',
        'workspace': 'workspace',
        'permalink_url': 'permalink_url',
        'public': 'public',
        'project_templates': 'project_templates'
    }

    def __init__(self, gid=None, resource_type=None, name=None, color=None, created_at=None, created_by=None, custom_field_settings=None, current_status_update=None, due_on=None, custom_fields=None, members=None, owner=None, start_on=None, workspace=None, permalink_url=None, public=None, project_templates=None):  # noqa: E501
        """PortfolioResponse - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._name = None
        self._color = None
        self._created_at = None
        self._created_by = None
        self._custom_field_settings = None
        self._current_status_update = None
        self._due_on = None
        self._custom_fields = None
        self._members = None
        self._owner = None
        self._start_on = None
        self._workspace = None
        self._permalink_url = None
        self._public = None
        self._project_templates = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if name is not None:
            self.name = name
        if color is not None:
            self.color = color
        if created_at is not None:
            self.created_at = created_at
        if created_by is not None:
            self.created_by = created_by
        if custom_field_settings is not None:
            self.custom_field_settings = custom_field_settings
        if current_status_update is not None:
            self.current_status_update = current_status_update
        if due_on is not None:
            self.due_on = due_on
        if custom_fields is not None:
            self.custom_fields = custom_fields
        if members is not None:
            self.members = members
        if owner is not None:
            self.owner = owner
        if start_on is not None:
            self.start_on = start_on
        if workspace is not None:
            self.workspace = workspace
        if permalink_url is not None:
            self.permalink_url = permalink_url
        if public is not None:
            self.public = public
        if project_templates is not None:
            self.project_templates = project_templates

    @property
    def gid(self):
        """Gets the gid of this PortfolioResponse.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this PortfolioResponse.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this PortfolioResponse.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this PortfolioResponse.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this PortfolioResponse.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this PortfolioResponse.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this PortfolioResponse.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this PortfolioResponse.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def name(self):
        """Gets the name of this PortfolioResponse.  # noqa: E501

        The name of the portfolio.  # noqa: E501

        :return: The name of this PortfolioResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PortfolioResponse.

        The name of the portfolio.  # noqa: E501

        :param name: The name of this PortfolioResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def color(self):
        """Gets the color of this PortfolioResponse.  # noqa: E501

        Color of the portfolio.  # noqa: E501

        :return: The color of this PortfolioResponse.  # noqa: E501
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this PortfolioResponse.

        Color of the portfolio.  # noqa: E501

        :param color: The color of this PortfolioResponse.  # noqa: E501
        :type: str
        """
        allowed_values = ["dark-pink", "dark-green", "dark-blue", "dark-red", "dark-teal", "dark-brown", "dark-orange", "dark-purple", "dark-warm-gray", "light-pink", "light-green", "light-blue", "light-red", "light-teal", "light-brown", "light-orange", "light-purple", "light-warm-gray"]  # noqa: E501
        if color not in allowed_values:
            raise ValueError(
                "Invalid value for `color` ({0}), must be one of {1}"  # noqa: E501
                .format(color, allowed_values)
            )

        self._color = color

    @property
    def created_at(self):
        """Gets the created_at of this PortfolioResponse.  # noqa: E501

        The time at which this resource was created.  # noqa: E501

        :return: The created_at of this PortfolioResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PortfolioResponse.

        The time at which this resource was created.  # noqa: E501

        :param created_at: The created_at of this PortfolioResponse.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def created_by(self):
        """Gets the created_by of this PortfolioResponse.  # noqa: E501


        :return: The created_by of this PortfolioResponse.  # noqa: E501
        :rtype: CustomFieldResponsePeopleValue
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this PortfolioResponse.


        :param created_by: The created_by of this PortfolioResponse.  # noqa: E501
        :type: CustomFieldResponsePeopleValue
        """

        self._created_by = created_by

    @property
    def custom_field_settings(self):
        """Gets the custom_field_settings of this PortfolioResponse.  # noqa: E501

        Array of custom field settings applied to the portfolio.  # noqa: E501

        :return: The custom_field_settings of this PortfolioResponse.  # noqa: E501
        :rtype: list[PortfolioResponseCustomFieldSettings]
        """
        return self._custom_field_settings

    @custom_field_settings.setter
    def custom_field_settings(self, custom_field_settings):
        """Sets the custom_field_settings of this PortfolioResponse.

        Array of custom field settings applied to the portfolio.  # noqa: E501

        :param custom_field_settings: The custom_field_settings of this PortfolioResponse.  # noqa: E501
        :type: list[PortfolioResponseCustomFieldSettings]
        """

        self._custom_field_settings = custom_field_settings

    @property
    def current_status_update(self):
        """Gets the current_status_update of this PortfolioResponse.  # noqa: E501


        :return: The current_status_update of this PortfolioResponse.  # noqa: E501
        :rtype: PortfolioResponseCurrentStatusUpdate
        """
        return self._current_status_update

    @current_status_update.setter
    def current_status_update(self, current_status_update):
        """Sets the current_status_update of this PortfolioResponse.


        :param current_status_update: The current_status_update of this PortfolioResponse.  # noqa: E501
        :type: PortfolioResponseCurrentStatusUpdate
        """

        self._current_status_update = current_status_update

    @property
    def due_on(self):
        """Gets the due_on of this PortfolioResponse.  # noqa: E501

        The localized day on which this portfolio is due. This takes a date with format YYYY-MM-DD.  # noqa: E501

        :return: The due_on of this PortfolioResponse.  # noqa: E501
        :rtype: date
        """
        return self._due_on

    @due_on.setter
    def due_on(self, due_on):
        """Sets the due_on of this PortfolioResponse.

        The localized day on which this portfolio is due. This takes a date with format YYYY-MM-DD.  # noqa: E501

        :param due_on: The due_on of this PortfolioResponse.  # noqa: E501
        :type: date
        """

        self._due_on = due_on

    @property
    def custom_fields(self):
        """Gets the custom_fields of this PortfolioResponse.  # noqa: E501

        Array of Custom Fields.  # noqa: E501

        :return: The custom_fields of this PortfolioResponse.  # noqa: E501
        :rtype: list[PortfolioResponseCustomFields]
        """
        return self._custom_fields

    @custom_fields.setter
    def custom_fields(self, custom_fields):
        """Sets the custom_fields of this PortfolioResponse.

        Array of Custom Fields.  # noqa: E501

        :param custom_fields: The custom_fields of this PortfolioResponse.  # noqa: E501
        :type: list[PortfolioResponseCustomFields]
        """

        self._custom_fields = custom_fields

    @property
    def members(self):
        """Gets the members of this PortfolioResponse.  # noqa: E501


        :return: The members of this PortfolioResponse.  # noqa: E501
        :rtype: list[CustomFieldResponsePeopleValue]
        """
        return self._members

    @members.setter
    def members(self, members):
        """Sets the members of this PortfolioResponse.


        :param members: The members of this PortfolioResponse.  # noqa: E501
        :type: list[CustomFieldResponsePeopleValue]
        """

        self._members = members

    @property
    def owner(self):
        """Gets the owner of this PortfolioResponse.  # noqa: E501


        :return: The owner of this PortfolioResponse.  # noqa: E501
        :rtype: CustomFieldResponsePeopleValue
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this PortfolioResponse.


        :param owner: The owner of this PortfolioResponse.  # noqa: E501
        :type: CustomFieldResponsePeopleValue
        """

        self._owner = owner

    @property
    def start_on(self):
        """Gets the start_on of this PortfolioResponse.  # noqa: E501

        The day on which work for this portfolio begins, or null if the portfolio has no start date. This takes a date with `YYYY-MM-DD` format. *Note: `due_on` must be present in the request when setting or unsetting the `start_on` parameter. Additionally, `start_on` and `due_on` cannot be the same date.*  # noqa: E501

        :return: The start_on of this PortfolioResponse.  # noqa: E501
        :rtype: date
        """
        return self._start_on

    @start_on.setter
    def start_on(self, start_on):
        """Sets the start_on of this PortfolioResponse.

        The day on which work for this portfolio begins, or null if the portfolio has no start date. This takes a date with `YYYY-MM-DD` format. *Note: `due_on` must be present in the request when setting or unsetting the `start_on` parameter. Additionally, `start_on` and `due_on` cannot be the same date.*  # noqa: E501

        :param start_on: The start_on of this PortfolioResponse.  # noqa: E501
        :type: date
        """

        self._start_on = start_on

    @property
    def workspace(self):
        """Gets the workspace of this PortfolioResponse.  # noqa: E501


        :return: The workspace of this PortfolioResponse.  # noqa: E501
        :rtype: PortfolioResponseWorkspace
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this PortfolioResponse.


        :param workspace: The workspace of this PortfolioResponse.  # noqa: E501
        :type: PortfolioResponseWorkspace
        """

        self._workspace = workspace

    @property
    def permalink_url(self):
        """Gets the permalink_url of this PortfolioResponse.  # noqa: E501

        A url that points directly to the object within Asana.  # noqa: E501

        :return: The permalink_url of this PortfolioResponse.  # noqa: E501
        :rtype: str
        """
        return self._permalink_url

    @permalink_url.setter
    def permalink_url(self, permalink_url):
        """Sets the permalink_url of this PortfolioResponse.

        A url that points directly to the object within Asana.  # noqa: E501

        :param permalink_url: The permalink_url of this PortfolioResponse.  # noqa: E501
        :type: str
        """

        self._permalink_url = permalink_url

    @property
    def public(self):
        """Gets the public of this PortfolioResponse.  # noqa: E501

        True if the portfolio is public to its workspace members.  # noqa: E501

        :return: The public of this PortfolioResponse.  # noqa: E501
        :rtype: bool
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this PortfolioResponse.

        True if the portfolio is public to its workspace members.  # noqa: E501

        :param public: The public of this PortfolioResponse.  # noqa: E501
        :type: bool
        """

        self._public = public

    @property
    def project_templates(self):
        """Gets the project_templates of this PortfolioResponse.  # noqa: E501

        Array of project templates that are in the portfolio  # noqa: E501

        :return: The project_templates of this PortfolioResponse.  # noqa: E501
        :rtype: list[JobBaseNewProjectTemplate]
        """
        return self._project_templates

    @project_templates.setter
    def project_templates(self, project_templates):
        """Sets the project_templates of this PortfolioResponse.

        Array of project templates that are in the portfolio  # noqa: E501

        :param project_templates: The project_templates of this PortfolioResponse.  # noqa: E501
        :type: list[JobBaseNewProjectTemplate]
        """

        self._project_templates = project_templates

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PortfolioResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PortfolioResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from asana.api_client import ApiClient


class ProjectTemplatesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_project_template(self, project_template_gid, **kwargs):  # noqa: E501
        """Delete a project template  # noqa: E501

        A specific, existing project template can be deleted by making a DELETE request on the URL for that project template.  Returns an empty data record.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_project_template(project_template_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_template_gid: Globally unique identifier for the project template. (required)
        :return: EmptyResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_project_template_with_http_info(project_template_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_project_template_with_http_info(project_template_gid, **kwargs)  # noqa: E501
            return data

    def delete_project_template_with_http_info(self, project_template_gid, **kwargs):  # noqa: E501
        """Delete a project template  # noqa: E501

        A specific, existing project template can be deleted by making a DELETE request on the URL for that project template.  Returns an empty data record.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_project_template_with_http_info(project_template_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_template_gid: Globally unique identifier for the project template. (required)
        :return: EmptyResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_template_gid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_project_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_template_gid' is set
        if ('project_template_gid' not in params or
                params['project_template_gid'] is None):
            raise ValueError("Missing the required parameter `project_template_gid` when calling `delete_project_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_template_gid' in params:
            path_params['project_template_gid'] = params['project_template_gid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/project_templates/{project_template_gid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_project_template(self, project_template_gid, **kwargs):  # noqa: E501
        """Get a project template  # noqa: E501

        Returns the complete project template record for a single project template.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_project_template(project_template_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_template_gid: Globally unique identifier for the project template. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: ProjectTemplateResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_project_template_with_http_info(project_template_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_project_template_with_http_info(project_template_gid, **kwargs)  # noqa: E501
            return data

    def get_project_template_with_http_info(self, project_template_gid, **kwargs):  # noqa: E501
        """Get a project template  # noqa: E501

        Returns the complete project template record for a single project template.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_project_template_with_http_info(project_template_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_template_gid: Globally unique identifier for the project template. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: ProjectTemplateResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_template_gid', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_project_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_template_gid' is set
        if ('project_template_gid' not in params or
                params['project_template_gid'] is None):
            raise ValueError("Missing the required parameter `project_template_gid` when calling `get_project_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_template_gid' in params:
            path_params['project_template_gid'] = params['project_template_gid']  # noqa: E501

        query_params = []
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/project_templates/{project_template_gid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectTemplateResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_project_templates(self, **kwargs):  # noqa: E501
        """Get multiple project templates  # noqa: E501

        Returns the compact project template records for all project templates in the given team or workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_project_templates(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: The workspace to filter results on.
        :param str team: The team to filter projects on.
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: ProjectTemplateResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_project_templates_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_project_templates_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_project_templates_with_http_info(self, **kwargs):  # noqa: E501
        """Get multiple project templates  # noqa: E501

        Returns the compact project template records for all project templates in the given team or workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_project_templates_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: The workspace to filter results on.
        :param str team: The team to filter projects on.
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: ProjectTemplateResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace', 'team', 'limit', 'offset', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_project_templates" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'workspace' in params:
            query_params.append(('workspace', params['workspace']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/project_templates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectTemplateResponseArray',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_project_templates_for_team(self, team_gid, **kwargs):  # noqa: E501
        """Get a team's project templates  # noqa: E501

        Returns the compact project template records for all project templates in the team.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_project_templates_for_team(team_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str team_gid: Globally unique identifier for the team. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: ProjectTemplateResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_project_templates_for_team_with_http_info(team_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_project_templates_for_team_with_http_info(team_gid, **kwargs)  # noqa: E501
            return data

    def get_project_templates_for_team_with_http_info(self, team_gid, **kwargs):  # noqa: E501
        """Get a team's project templates  # noqa: E501

        Returns the compact project template records for all project templates in the team.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_project_templates_for_team_with_http_info(team_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str team_gid: Globally unique identifier for the team. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: ProjectTemplateResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_gid', 'limit', 'offset', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_project_templates_for_team" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_gid' is set
        if ('team_gid' not in params or
                params['team_gid'] is None):
            raise ValueError("Missing the required parameter `team_gid` when calling `get_project_templates_for_team`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_gid' in params:
            path_params['team_gid'] = params['team_gid']  # noqa: E501

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/teams/{team_gid}/project_templates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectTemplateResponseArray',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def instantiate_project(self, project_template_gid, **kwargs):  # noqa: E501
        """Instantiate a project from a project template  # noqa: E501

        Creates and returns a job that will asynchronously handle the project instantiation.  To form this request, it is recommended to first make a request to [get a project template](/reference/getprojecttemplate). Then, from the response, copy the `gid` from the object in the `requested_dates` array. This `gid` should be used in `requested_dates` to instantiate a project.  _Note: The body of this request will differ if your workspace is an organization. To determine if your workspace is an organization, use the [is_organization](/reference/workspaces) parameter._  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.instantiate_project(project_template_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_template_gid: Globally unique identifier for the project template. (required)
        :param ProjectTemplateGidInstantiateProjectBody body: Describes the inputs used for instantiating a project, such as the resulting project's name, which team it should be created in, and values for date variables.
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: JobResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.instantiate_project_with_http_info(project_template_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.instantiate_project_with_http_info(project_template_gid, **kwargs)  # noqa: E501
            return data

    def instantiate_project_with_http_info(self, project_template_gid, **kwargs):  # noqa: E501
        """Instantiate a project from a project template  # noqa: E501

        Creates and returns a job that will asynchronously handle the project instantiation.  To form this request, it is recommended to first make a request to [get a project template](/reference/getprojecttemplate). Then, from the response, copy the `gid` from the object in the `requested_dates` array. This `gid` should be used in `requested_dates` to instantiate a project.  _Note: The body of this request will differ if your workspace is an organization. To determine if your workspace is an organization, use the [is_organization](/reference/workspaces) parameter._  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.instantiate_project_with_http_info(project_template_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_template_gid: Globally unique identifier for the project template. (required)
        :param ProjectTemplateGidInstantiateProjectBody body: Describes the inputs used for instantiating a project, such as the resulting project's name, which team it should be created in, and values for date variables.
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: JobResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_template_gid', 'body', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method instantiate_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_template_gid' is set
        if ('project_template_gid' not in params or
                params['project_template_gid'] is None):
            raise ValueError("Missing the required parameter `project_template_gid` when calling `instantiate_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_template_gid' in params:
            path_params['project_template_gid'] = params['project_template_gid']  # noqa: E501

        query_params = []
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/project_templates/{project_template_gid}/instantiateProject', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OrganizationExportCompact(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'created_at': 'datetime',
        'download_url': 'str',
        'state': 'str',
        'organization': 'GoalResponseWorkspace'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'created_at': 'created_at',
        'download_url': 'download_url',
        'state': 'state',
        'organization': 'organization'
    }

    def __init__(self, gid=None, resource_type=None, created_at=None, download_url=None, state=None, organization=None):  # noqa: E501
        """OrganizationExportCompact - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._created_at = None
        self._download_url = None
        self._state = None
        self._organization = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if created_at is not None:
            self.created_at = created_at
        if download_url is not None:
            self.download_url = download_url
        if state is not None:
            self.state = state
        if organization is not None:
            self.organization = organization

    @property
    def gid(self):
        """Gets the gid of this OrganizationExportCompact.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this OrganizationExportCompact.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this OrganizationExportCompact.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this OrganizationExportCompact.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this OrganizationExportCompact.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this OrganizationExportCompact.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this OrganizationExportCompact.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this OrganizationExportCompact.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def created_at(self):
        """Gets the created_at of this OrganizationExportCompact.  # noqa: E501

        The time at which this resource was created.  # noqa: E501

        :return: The created_at of this OrganizationExportCompact.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this OrganizationExportCompact.

        The time at which this resource was created.  # noqa: E501

        :param created_at: The created_at of this OrganizationExportCompact.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def download_url(self):
        """Gets the download_url of this OrganizationExportCompact.  # noqa: E501

        Download this URL to retreive the full export of the organization in JSON format. It will be compressed in a gzip (.gz) container.  *Note: May be null if the export is still in progress or failed.  If present, this URL may only be valid for 1 hour from the time of retrieval. You should avoid persisting this URL somewhere and rather refresh on demand to ensure you do not keep stale URLs.*  # noqa: E501

        :return: The download_url of this OrganizationExportCompact.  # noqa: E501
        :rtype: str
        """
        return self._download_url

    @download_url.setter
    def download_url(self, download_url):
        """Sets the download_url of this OrganizationExportCompact.

        Download this URL to retreive the full export of the organization in JSON format. It will be compressed in a gzip (.gz) container.  *Note: May be null if the export is still in progress or failed.  If present, this URL may only be valid for 1 hour from the time of retrieval. You should avoid persisting this URL somewhere and rather refresh on demand to ensure you do not keep stale URLs.*  # noqa: E501

        :param download_url: The download_url of this OrganizationExportCompact.  # noqa: E501
        :type: str
        """

        self._download_url = download_url

    @property
    def state(self):
        """Gets the state of this OrganizationExportCompact.  # noqa: E501

        The current state of the export.  # noqa: E501

        :return: The state of this OrganizationExportCompact.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this OrganizationExportCompact.

        The current state of the export.  # noqa: E501

        :param state: The state of this OrganizationExportCompact.  # noqa: E501
        :type: str
        """
        allowed_values = ["pending", "started", "finished", "error"]  # noqa: E501
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    @property
    def organization(self):
        """Gets the organization of this OrganizationExportCompact.  # noqa: E501


        :return: The organization of this OrganizationExportCompact.  # noqa: E501
        :rtype: GoalResponseWorkspace
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this OrganizationExportCompact.


        :param organization: The organization of this OrganizationExportCompact.  # noqa: E501
        :type: GoalResponseWorkspace
        """

        self._organization = organization

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrganizationExportCompact, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrganizationExportCompact):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from asana.api_client import ApiClient


class TimePeriodsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_time_period(self, time_period_gid, **kwargs):  # noqa: E501
        """Get a time period  # noqa: E501

        Returns the full record for a single time period.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_time_period(time_period_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str time_period_gid: Globally unique identifier for the time period. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: TimePeriodResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_time_period_with_http_info(time_period_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_time_period_with_http_info(time_period_gid, **kwargs)  # noqa: E501
            return data

    def get_time_period_with_http_info(self, time_period_gid, **kwargs):  # noqa: E501
        """Get a time period  # noqa: E501

        Returns the full record for a single time period.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_time_period_with_http_info(time_period_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str time_period_gid: Globally unique identifier for the time period. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: TimePeriodResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['time_period_gid', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_time_period" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'time_period_gid' is set
        if ('time_period_gid' not in params or
                params['time_period_gid'] is None):
            raise ValueError("Missing the required parameter `time_period_gid` when calling `get_time_period`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'time_period_gid' in params:
            path_params['time_period_gid'] = params['time_period_gid']  # noqa: E501

        query_params = []
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/time_periods/{time_period_gid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TimePeriodResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_time_periods(self, workspace, **kwargs):  # noqa: E501
        """Get time periods  # noqa: E501

        Returns compact time period records.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_time_periods(workspace, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: Globally unique identifier for the workspace. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param date start_on: ISO 8601 date string
        :param date end_on: ISO 8601 date string
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: TimePeriodResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_time_periods_with_http_info(workspace, **kwargs)  # noqa: E501
        else:
            (data) = self.get_time_periods_with_http_info(workspace, **kwargs)  # noqa: E501
            return data

    def get_time_periods_with_http_info(self, workspace, **kwargs):  # noqa: E501
        """Get time periods  # noqa: E501

        Returns compact time period records.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_time_periods_with_http_info(workspace, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: Globally unique identifier for the workspace. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param date start_on: ISO 8601 date string
        :param date end_on: ISO 8601 date string
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: TimePeriodResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace', 'limit', 'offset', 'start_on', 'end_on', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_time_periods" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace' is set
        if ('workspace' not in params or
                params['workspace'] is None):
            raise ValueError("Missing the required parameter `workspace` when calling `get_time_periods`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'start_on' in params:
            query_params.append(('start_on', params['start_on']))  # noqa: E501
        if 'end_on' in params:
            query_params.append(('end_on', params['end_on']))  # noqa: E501
        if 'workspace' in params:
            query_params.append(('workspace', params['workspace']))  # noqa: E501
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/time_periods', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TimePeriodResponseArray',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProjectDuplicateRequestScheduleDates(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'should_skip_weekends': 'bool',
        'due_on': 'str',
        'start_on': 'str'
    }

    attribute_map = {
        'should_skip_weekends': 'should_skip_weekends',
        'due_on': 'due_on',
        'start_on': 'start_on'
    }

    def __init__(self, should_skip_weekends=None, due_on=None, start_on=None):  # noqa: E501
        """ProjectDuplicateRequestScheduleDates - a model defined in Swagger"""  # noqa: E501
        self._should_skip_weekends = None
        self._due_on = None
        self._start_on = None
        self.discriminator = None
        self.should_skip_weekends = should_skip_weekends
        if due_on is not None:
            self.due_on = due_on
        if start_on is not None:
            self.start_on = start_on

    @property
    def should_skip_weekends(self):
        """Gets the should_skip_weekends of this ProjectDuplicateRequestScheduleDates.  # noqa: E501

        Determines if the auto-shifted dates should skip weekends.  # noqa: E501

        :return: The should_skip_weekends of this ProjectDuplicateRequestScheduleDates.  # noqa: E501
        :rtype: bool
        """
        return self._should_skip_weekends

    @should_skip_weekends.setter
    def should_skip_weekends(self, should_skip_weekends):
        """Sets the should_skip_weekends of this ProjectDuplicateRequestScheduleDates.

        Determines if the auto-shifted dates should skip weekends.  # noqa: E501

        :param should_skip_weekends: The should_skip_weekends of this ProjectDuplicateRequestScheduleDates.  # noqa: E501
        :type: bool
        """
        if should_skip_weekends is None:
            raise ValueError("Invalid value for `should_skip_weekends`, must not be `None`")  # noqa: E501

        self._should_skip_weekends = should_skip_weekends

    @property
    def due_on(self):
        """Gets the due_on of this ProjectDuplicateRequestScheduleDates.  # noqa: E501

        Sets the last due date in the duplicated project to the given date. The rest of the due dates will be offset by the same amount as the due dates in the original project.  # noqa: E501

        :return: The due_on of this ProjectDuplicateRequestScheduleDates.  # noqa: E501
        :rtype: str
        """
        return self._due_on

    @due_on.setter
    def due_on(self, due_on):
        """Sets the due_on of this ProjectDuplicateRequestScheduleDates.

        Sets the last due date in the duplicated project to the given date. The rest of the due dates will be offset by the same amount as the due dates in the original project.  # noqa: E501

        :param due_on: The due_on of this ProjectDuplicateRequestScheduleDates.  # noqa: E501
        :type: str
        """

        self._due_on = due_on

    @property
    def start_on(self):
        """Gets the start_on of this ProjectDuplicateRequestScheduleDates.  # noqa: E501

        Sets the first start date in the duplicated project to the given date. The rest of the start dates will be offset by the same amount as the start dates in the original project.  # noqa: E501

        :return: The start_on of this ProjectDuplicateRequestScheduleDates.  # noqa: E501
        :rtype: str
        """
        return self._start_on

    @start_on.setter
    def start_on(self, start_on):
        """Sets the start_on of this ProjectDuplicateRequestScheduleDates.

        Sets the first start date in the duplicated project to the given date. The rest of the start dates will be offset by the same amount as the start dates in the original project.  # noqa: E501

        :param start_on: The start_on of this ProjectDuplicateRequestScheduleDates.  # noqa: E501
        :type: str
        """

        self._start_on = start_on

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectDuplicateRequestScheduleDates, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectDuplicateRequestScheduleDates):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CustomFieldRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'name': 'str',
        'resource_subtype': 'str',
        'type': 'str',
        'enum_options': 'list[CustomFieldBaseEnumOptions]',
        'enabled': 'bool',
        'is_formula_field': 'bool',
        'date_value': 'CustomFieldBaseDateValue',
        'enum_value': 'CustomFieldBaseEnumValue',
        'multi_enum_values': 'list[CustomFieldBaseEnumOptions]',
        'number_value': 'float',
        'text_value': 'str',
        'display_value': 'str',
        'description': 'str',
        'precision': 'int',
        'format': 'str',
        'currency_code': 'str',
        'custom_label': 'str',
        'custom_label_position': 'str',
        'is_global_to_workspace': 'bool',
        'has_notifications_enabled': 'bool',
        'asana_created_field': 'str',
        'workspace': 'str',
        'owned_by_app': 'bool',
        'people_value': 'list[str]'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'name': 'name',
        'resource_subtype': 'resource_subtype',
        'type': 'type',
        'enum_options': 'enum_options',
        'enabled': 'enabled',
        'is_formula_field': 'is_formula_field',
        'date_value': 'date_value',
        'enum_value': 'enum_value',
        'multi_enum_values': 'multi_enum_values',
        'number_value': 'number_value',
        'text_value': 'text_value',
        'display_value': 'display_value',
        'description': 'description',
        'precision': 'precision',
        'format': 'format',
        'currency_code': 'currency_code',
        'custom_label': 'custom_label',
        'custom_label_position': 'custom_label_position',
        'is_global_to_workspace': 'is_global_to_workspace',
        'has_notifications_enabled': 'has_notifications_enabled',
        'asana_created_field': 'asana_created_field',
        'workspace': 'workspace',
        'owned_by_app': 'owned_by_app',
        'people_value': 'people_value'
    }

    def __init__(self, gid=None, resource_type=None, name=None, resource_subtype=None, type=None, enum_options=None, enabled=None, is_formula_field=None, date_value=None, enum_value=None, multi_enum_values=None, number_value=None, text_value=None, display_value=None, description=None, precision=None, format=None, currency_code=None, custom_label=None, custom_label_position=None, is_global_to_workspace=None, has_notifications_enabled=None, asana_created_field=None, workspace=None, owned_by_app=None, people_value=None):  # noqa: E501
        """CustomFieldRequest - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._name = None
        self._resource_subtype = None
        self._type = None
        self._enum_options = None
        self._enabled = None
        self._is_formula_field = None
        self._date_value = None
        self._enum_value = None
        self._multi_enum_values = None
        self._number_value = None
        self._text_value = None
        self._display_value = None
        self._description = None
        self._precision = None
        self._format = None
        self._currency_code = None
        self._custom_label = None
        self._custom_label_position = None
        self._is_global_to_workspace = None
        self._has_notifications_enabled = None
        self._asana_created_field = None
        self._workspace = None
        self._owned_by_app = None
        self._people_value = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if name is not None:
            self.name = name
        if resource_subtype is not None:
            self.resource_subtype = resource_subtype
        if type is not None:
            self.type = type
        if enum_options is not None:
            self.enum_options = enum_options
        if enabled is not None:
            self.enabled = enabled
        if is_formula_field is not None:
            self.is_formula_field = is_formula_field
        if date_value is not None:
            self.date_value = date_value
        if enum_value is not None:
            self.enum_value = enum_value
        if multi_enum_values is not None:
            self.multi_enum_values = multi_enum_values
        if number_value is not None:
            self.number_value = number_value
        if text_value is not None:
            self.text_value = text_value
        if display_value is not None:
            self.display_value = display_value
        if description is not None:
            self.description = description
        if precision is not None:
            self.precision = precision
        if format is not None:
            self.format = format
        if currency_code is not None:
            self.currency_code = currency_code
        if custom_label is not None:
            self.custom_label = custom_label
        if custom_label_position is not None:
            self.custom_label_position = custom_label_position
        if is_global_to_workspace is not None:
            self.is_global_to_workspace = is_global_to_workspace
        if has_notifications_enabled is not None:
            self.has_notifications_enabled = has_notifications_enabled
        if asana_created_field is not None:
            self.asana_created_field = asana_created_field
        self.workspace = workspace
        if owned_by_app is not None:
            self.owned_by_app = owned_by_app
        if people_value is not None:
            self.people_value = people_value

    @property
    def gid(self):
        """Gets the gid of this CustomFieldRequest.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this CustomFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this CustomFieldRequest.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this CustomFieldRequest.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this CustomFieldRequest.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this CustomFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this CustomFieldRequest.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this CustomFieldRequest.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def name(self):
        """Gets the name of this CustomFieldRequest.  # noqa: E501

        The name of the custom field.  # noqa: E501

        :return: The name of this CustomFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CustomFieldRequest.

        The name of the custom field.  # noqa: E501

        :param name: The name of this CustomFieldRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def resource_subtype(self):
        """Gets the resource_subtype of this CustomFieldRequest.  # noqa: E501

        The type of the custom field. Must be one of the given values.   # noqa: E501

        :return: The resource_subtype of this CustomFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._resource_subtype

    @resource_subtype.setter
    def resource_subtype(self, resource_subtype):
        """Sets the resource_subtype of this CustomFieldRequest.

        The type of the custom field. Must be one of the given values.   # noqa: E501

        :param resource_subtype: The resource_subtype of this CustomFieldRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["text", "enum", "multi_enum", "number", "date", "people"]  # noqa: E501
        if resource_subtype not in allowed_values:
            raise ValueError(
                "Invalid value for `resource_subtype` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_subtype, allowed_values)
            )

        self._resource_subtype = resource_subtype

    @property
    def type(self):
        """Gets the type of this CustomFieldRequest.  # noqa: E501

        *Deprecated: new integrations should prefer the resource_subtype field.* The type of the custom field. Must be one of the given values.   # noqa: E501

        :return: The type of this CustomFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CustomFieldRequest.

        *Deprecated: new integrations should prefer the resource_subtype field.* The type of the custom field. Must be one of the given values.   # noqa: E501

        :param type: The type of this CustomFieldRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["text", "enum", "multi_enum", "number", "date", "people"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def enum_options(self):
        """Gets the enum_options of this CustomFieldRequest.  # noqa: E501

        *Conditional*. Only relevant for custom fields of type `enum`. This array specifies the possible values which an `enum` custom field can adopt. To modify the enum options, refer to [working with enum options](/reference/createenumoptionforcustomfield).  # noqa: E501

        :return: The enum_options of this CustomFieldRequest.  # noqa: E501
        :rtype: list[CustomFieldBaseEnumOptions]
        """
        return self._enum_options

    @enum_options.setter
    def enum_options(self, enum_options):
        """Sets the enum_options of this CustomFieldRequest.

        *Conditional*. Only relevant for custom fields of type `enum`. This array specifies the possible values which an `enum` custom field can adopt. To modify the enum options, refer to [working with enum options](/reference/createenumoptionforcustomfield).  # noqa: E501

        :param enum_options: The enum_options of this CustomFieldRequest.  # noqa: E501
        :type: list[CustomFieldBaseEnumOptions]
        """

        self._enum_options = enum_options

    @property
    def enabled(self):
        """Gets the enabled of this CustomFieldRequest.  # noqa: E501

        *Conditional*. Determines if the custom field is enabled or not.  # noqa: E501

        :return: The enabled of this CustomFieldRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this CustomFieldRequest.

        *Conditional*. Determines if the custom field is enabled or not.  # noqa: E501

        :param enabled: The enabled of this CustomFieldRequest.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def is_formula_field(self):
        """Gets the is_formula_field of this CustomFieldRequest.  # noqa: E501

        *Conditional*. This flag describes whether a custom field is a formula custom field.  # noqa: E501

        :return: The is_formula_field of this CustomFieldRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_formula_field

    @is_formula_field.setter
    def is_formula_field(self, is_formula_field):
        """Sets the is_formula_field of this CustomFieldRequest.

        *Conditional*. This flag describes whether a custom field is a formula custom field.  # noqa: E501

        :param is_formula_field: The is_formula_field of this CustomFieldRequest.  # noqa: E501
        :type: bool
        """

        self._is_formula_field = is_formula_field

    @property
    def date_value(self):
        """Gets the date_value of this CustomFieldRequest.  # noqa: E501


        :return: The date_value of this CustomFieldRequest.  # noqa: E501
        :rtype: CustomFieldBaseDateValue
        """
        return self._date_value

    @date_value.setter
    def date_value(self, date_value):
        """Sets the date_value of this CustomFieldRequest.


        :param date_value: The date_value of this CustomFieldRequest.  # noqa: E501
        :type: CustomFieldBaseDateValue
        """

        self._date_value = date_value

    @property
    def enum_value(self):
        """Gets the enum_value of this CustomFieldRequest.  # noqa: E501


        :return: The enum_value of this CustomFieldRequest.  # noqa: E501
        :rtype: CustomFieldBaseEnumValue
        """
        return self._enum_value

    @enum_value.setter
    def enum_value(self, enum_value):
        """Sets the enum_value of this CustomFieldRequest.


        :param enum_value: The enum_value of this CustomFieldRequest.  # noqa: E501
        :type: CustomFieldBaseEnumValue
        """

        self._enum_value = enum_value

    @property
    def multi_enum_values(self):
        """Gets the multi_enum_values of this CustomFieldRequest.  # noqa: E501

        *Conditional*. Only relevant for custom fields of type `multi_enum`. This object is the chosen values of a `multi_enum` custom field.  # noqa: E501

        :return: The multi_enum_values of this CustomFieldRequest.  # noqa: E501
        :rtype: list[CustomFieldBaseEnumOptions]
        """
        return self._multi_enum_values

    @multi_enum_values.setter
    def multi_enum_values(self, multi_enum_values):
        """Sets the multi_enum_values of this CustomFieldRequest.

        *Conditional*. Only relevant for custom fields of type `multi_enum`. This object is the chosen values of a `multi_enum` custom field.  # noqa: E501

        :param multi_enum_values: The multi_enum_values of this CustomFieldRequest.  # noqa: E501
        :type: list[CustomFieldBaseEnumOptions]
        """

        self._multi_enum_values = multi_enum_values

    @property
    def number_value(self):
        """Gets the number_value of this CustomFieldRequest.  # noqa: E501

        *Conditional*. This number is the value of a `number` custom field.  # noqa: E501

        :return: The number_value of this CustomFieldRequest.  # noqa: E501
        :rtype: float
        """
        return self._number_value

    @number_value.setter
    def number_value(self, number_value):
        """Sets the number_value of this CustomFieldRequest.

        *Conditional*. This number is the value of a `number` custom field.  # noqa: E501

        :param number_value: The number_value of this CustomFieldRequest.  # noqa: E501
        :type: float
        """

        self._number_value = number_value

    @property
    def text_value(self):
        """Gets the text_value of this CustomFieldRequest.  # noqa: E501

        *Conditional*. This string is the value of a `text` custom field.  # noqa: E501

        :return: The text_value of this CustomFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._text_value

    @text_value.setter
    def text_value(self, text_value):
        """Sets the text_value of this CustomFieldRequest.

        *Conditional*. This string is the value of a `text` custom field.  # noqa: E501

        :param text_value: The text_value of this CustomFieldRequest.  # noqa: E501
        :type: str
        """

        self._text_value = text_value

    @property
    def display_value(self):
        """Gets the display_value of this CustomFieldRequest.  # noqa: E501

        A string representation for the value of the custom field. Integrations that don't require the underlying type should use this field to read values. Using this field will future-proof an app against new custom field types.  # noqa: E501

        :return: The display_value of this CustomFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._display_value

    @display_value.setter
    def display_value(self, display_value):
        """Sets the display_value of this CustomFieldRequest.

        A string representation for the value of the custom field. Integrations that don't require the underlying type should use this field to read values. Using this field will future-proof an app against new custom field types.  # noqa: E501

        :param display_value: The display_value of this CustomFieldRequest.  # noqa: E501
        :type: str
        """

        self._display_value = display_value

    @property
    def description(self):
        """Gets the description of this CustomFieldRequest.  # noqa: E501

        [Opt In](/docs/inputoutput-options). The description of the custom field.  # noqa: E501

        :return: The description of this CustomFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CustomFieldRequest.

        [Opt In](/docs/inputoutput-options). The description of the custom field.  # noqa: E501

        :param description: The description of this CustomFieldRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def precision(self):
        """Gets the precision of this CustomFieldRequest.  # noqa: E501

        Only relevant for custom fields of type ‘Number’. This field dictates the number of places after the decimal to round to, i.e. 0 is integer values, 1 rounds to the nearest tenth, and so on. Must be between 0 and 6, inclusive. For percentage format, this may be unintuitive, as a value of 0.25 has a precision of 0, while a value of 0.251 has a precision of 1. This is due to 0.25 being displayed as 25%. The identifier format will always have a precision of 0.  # noqa: E501

        :return: The precision of this CustomFieldRequest.  # noqa: E501
        :rtype: int
        """
        return self._precision

    @precision.setter
    def precision(self, precision):
        """Sets the precision of this CustomFieldRequest.

        Only relevant for custom fields of type ‘Number’. This field dictates the number of places after the decimal to round to, i.e. 0 is integer values, 1 rounds to the nearest tenth, and so on. Must be between 0 and 6, inclusive. For percentage format, this may be unintuitive, as a value of 0.25 has a precision of 0, while a value of 0.251 has a precision of 1. This is due to 0.25 being displayed as 25%. The identifier format will always have a precision of 0.  # noqa: E501

        :param precision: The precision of this CustomFieldRequest.  # noqa: E501
        :type: int
        """

        self._precision = precision

    @property
    def format(self):
        """Gets the format of this CustomFieldRequest.  # noqa: E501

        The format of this custom field.  # noqa: E501

        :return: The format of this CustomFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this CustomFieldRequest.

        The format of this custom field.  # noqa: E501

        :param format: The format of this CustomFieldRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["currency", "identifier", "percentage", "custom", "duration", "none"]  # noqa: E501
        if format not in allowed_values:
            raise ValueError(
                "Invalid value for `format` ({0}), must be one of {1}"  # noqa: E501
                .format(format, allowed_values)
            )

        self._format = format

    @property
    def currency_code(self):
        """Gets the currency_code of this CustomFieldRequest.  # noqa: E501

        ISO 4217 currency code to format this custom field. This will be null if the `format` is not `currency`.  # noqa: E501

        :return: The currency_code of this CustomFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this CustomFieldRequest.

        ISO 4217 currency code to format this custom field. This will be null if the `format` is not `currency`.  # noqa: E501

        :param currency_code: The currency_code of this CustomFieldRequest.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def custom_label(self):
        """Gets the custom_label of this CustomFieldRequest.  # noqa: E501

        This is the string that appears next to the custom field value. This will be null if the `format` is not `custom`.  # noqa: E501

        :return: The custom_label of this CustomFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._custom_label

    @custom_label.setter
    def custom_label(self, custom_label):
        """Sets the custom_label of this CustomFieldRequest.

        This is the string that appears next to the custom field value. This will be null if the `format` is not `custom`.  # noqa: E501

        :param custom_label: The custom_label of this CustomFieldRequest.  # noqa: E501
        :type: str
        """

        self._custom_label = custom_label

    @property
    def custom_label_position(self):
        """Gets the custom_label_position of this CustomFieldRequest.  # noqa: E501

        Only relevant for custom fields with `custom` format. This depicts where to place the custom label. This will be null if the `format` is not `custom`.  # noqa: E501

        :return: The custom_label_position of this CustomFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._custom_label_position

    @custom_label_position.setter
    def custom_label_position(self, custom_label_position):
        """Sets the custom_label_position of this CustomFieldRequest.

        Only relevant for custom fields with `custom` format. This depicts where to place the custom label. This will be null if the `format` is not `custom`.  # noqa: E501

        :param custom_label_position: The custom_label_position of this CustomFieldRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["prefix", "suffix", ""]  # noqa: E501
        if custom_label_position not in allowed_values:
            raise ValueError(
                "Invalid value for `custom_label_position` ({0}), must be one of {1}"  # noqa: E501
                .format(custom_label_position, allowed_values)
            )

        self._custom_label_position = custom_label_position

    @property
    def is_global_to_workspace(self):
        """Gets the is_global_to_workspace of this CustomFieldRequest.  # noqa: E501

        This flag describes whether this custom field is available to every container in the workspace. Before project-specific custom fields, this field was always true.  # noqa: E501

        :return: The is_global_to_workspace of this CustomFieldRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_global_to_workspace

    @is_global_to_workspace.setter
    def is_global_to_workspace(self, is_global_to_workspace):
        """Sets the is_global_to_workspace of this CustomFieldRequest.

        This flag describes whether this custom field is available to every container in the workspace. Before project-specific custom fields, this field was always true.  # noqa: E501

        :param is_global_to_workspace: The is_global_to_workspace of this CustomFieldRequest.  # noqa: E501
        :type: bool
        """

        self._is_global_to_workspace = is_global_to_workspace

    @property
    def has_notifications_enabled(self):
        """Gets the has_notifications_enabled of this CustomFieldRequest.  # noqa: E501

        *Conditional*. This flag describes whether a follower of a task with this field should receive inbox notifications from changes to this field.  # noqa: E501

        :return: The has_notifications_enabled of this CustomFieldRequest.  # noqa: E501
        :rtype: bool
        """
        return self._has_notifications_enabled

    @has_notifications_enabled.setter
    def has_notifications_enabled(self, has_notifications_enabled):
        """Sets the has_notifications_enabled of this CustomFieldRequest.

        *Conditional*. This flag describes whether a follower of a task with this field should receive inbox notifications from changes to this field.  # noqa: E501

        :param has_notifications_enabled: The has_notifications_enabled of this CustomFieldRequest.  # noqa: E501
        :type: bool
        """

        self._has_notifications_enabled = has_notifications_enabled

    @property
    def asana_created_field(self):
        """Gets the asana_created_field of this CustomFieldRequest.  # noqa: E501

        *Conditional*. A unique identifier to associate this field with the template source of truth.  # noqa: E501

        :return: The asana_created_field of this CustomFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._asana_created_field

    @asana_created_field.setter
    def asana_created_field(self, asana_created_field):
        """Sets the asana_created_field of this CustomFieldRequest.

        *Conditional*. A unique identifier to associate this field with the template source of truth.  # noqa: E501

        :param asana_created_field: The asana_created_field of this CustomFieldRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["a_v_requirements", "account_name", "actionable", "align_shipping_link", "align_status", "allotted_time", "appointment", "approval_stage", "approved", "article_series", "board_committee", "browser", "campaign_audience", "campaign_project_status", "campaign_regions", "channel_primary", "client_topic_type", "complete_by", "contact", "contact_email_address", "content_channels", "content_channels_needed", "content_stage", "content_type", "contract", "contract_status", "cost", "creation_stage", "creative_channel", "creative_needed", "creative_needs", "data_sensitivity", "deal_size", "delivery_appt", "delivery_appt_date", "department", "department_responsible", "design_request_needed", "design_request_type", "discussion_category", "do_this_task", "editorial_content_status", "editorial_content_tag", "editorial_content_type", "effort", "effort_level", "est_completion_date", "estimated_time", "estimated_value", "expected_cost", "external_steps_needed", "favorite_idea", "feedback_type", "financial", "funding_amount", "grant_application_process", "hiring_candidate_status", "idea_status", "ids_link", "ids_patient_link", "implementation_stage", "insurance", "interview_area", "interview_question_score", "itero_scan_link", "job_s_applied_to", "lab", "launch_status", "lead_status", "localization_language", "localization_market_team", "localization_status", "meeting_minutes", "meeting_needed", "minutes", "mrr", "must_localize", "name_of_foundation", "need_to_follow_up", "next_appointment", "next_steps_sales", "num_people", "number_of_user_reports", "office_location", "onboarding_activity", "owner", "participants_needed", "patient_date_of_birth", "patient_email", "patient_phone", "patient_status", "phone_number", "planning_category", "point_of_contact", "position", "post_format", "prescription", "priority", "priority_level", "product", "product_stage", "progress", "project_size", "project_status", "proposed_budget", "publish_status", "reason_for_scan", "referral", "request_type", "research_status", "responsible_department", "responsible_team", "risk_assessment_status", "room_name", "sales_counterpart", "sentiment", "shipping_link", "social_channels", "stage", "status", "status_design", "status_of_initiative", "system_setup", "task_progress", "team", "team_marketing", "team_responsible", "time_it_takes_to_complete_tasks", "timeframe", "treatment_type", "type_work_requests_it", "use_agency", "user_name", "vendor_category", "vendor_type", "word_count", ""]  # noqa: E501
        if asana_created_field not in allowed_values:
            raise ValueError(
                "Invalid value for `asana_created_field` ({0}), must be one of {1}"  # noqa: E501
                .format(asana_created_field, allowed_values)
            )

        self._asana_created_field = asana_created_field

    @property
    def workspace(self):
        """Gets the workspace of this CustomFieldRequest.  # noqa: E501

        *Create-Only* The workspace to create a custom field in.  # noqa: E501

        :return: The workspace of this CustomFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this CustomFieldRequest.

        *Create-Only* The workspace to create a custom field in.  # noqa: E501

        :param workspace: The workspace of this CustomFieldRequest.  # noqa: E501
        :type: str
        """
        if workspace is None:
            raise ValueError("Invalid value for `workspace`, must not be `None`")  # noqa: E501

        self._workspace = workspace

    @property
    def owned_by_app(self):
        """Gets the owned_by_app of this CustomFieldRequest.  # noqa: E501

        *Allow-listed*. Instructs the API that this Custom Field is app-owned. This parameter is allow-listed to specific apps at this point in time. For apps that are not allow-listed, providing this parameter will result in a `403 Forbidden`.  # noqa: E501

        :return: The owned_by_app of this CustomFieldRequest.  # noqa: E501
        :rtype: bool
        """
        return self._owned_by_app

    @owned_by_app.setter
    def owned_by_app(self, owned_by_app):
        """Sets the owned_by_app of this CustomFieldRequest.

        *Allow-listed*. Instructs the API that this Custom Field is app-owned. This parameter is allow-listed to specific apps at this point in time. For apps that are not allow-listed, providing this parameter will result in a `403 Forbidden`.  # noqa: E501

        :param owned_by_app: The owned_by_app of this CustomFieldRequest.  # noqa: E501
        :type: bool
        """

        self._owned_by_app = owned_by_app

    @property
    def people_value(self):
        """Gets the people_value of this CustomFieldRequest.  # noqa: E501

        *Conditional*. Only relevant for custom fields of type `people`. This array of user GIDs reflects the users to be written to a `people` custom field. Note that *write* operations will replace existing users (if any) in the custom field with the users specified in this array.  # noqa: E501

        :return: The people_value of this CustomFieldRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._people_value

    @people_value.setter
    def people_value(self, people_value):
        """Sets the people_value of this CustomFieldRequest.

        *Conditional*. Only relevant for custom fields of type `people`. This array of user GIDs reflects the users to be written to a `people` custom field. Note that *write* operations will replace existing users (if any) in the custom field with the users specified in this array.  # noqa: E501

        :param people_value: The people_value of this CustomFieldRequest.  # noqa: E501
        :type: list[str]
        """

        self._people_value = people_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustomFieldRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomFieldRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from asana.api_client import ApiClient


class SectionsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_task_for_section(self, section_gid, **kwargs):  # noqa: E501
        """Add task to section  # noqa: E501

        Add a task to a specific, existing section. This will remove the task from other sections of the project.  The task will be inserted at the top of a section unless an insert_before or insert_after parameter is declared.  This does not work for separators (tasks with the resource_subtype of section).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_task_for_section(section_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str section_gid: The globally unique identifier for the section. (required)
        :param SectionGidAddTaskBody body: The task and optionally the insert location.
        :return: EmptyResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_task_for_section_with_http_info(section_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.add_task_for_section_with_http_info(section_gid, **kwargs)  # noqa: E501
            return data

    def add_task_for_section_with_http_info(self, section_gid, **kwargs):  # noqa: E501
        """Add task to section  # noqa: E501

        Add a task to a specific, existing section. This will remove the task from other sections of the project.  The task will be inserted at the top of a section unless an insert_before or insert_after parameter is declared.  This does not work for separators (tasks with the resource_subtype of section).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_task_for_section_with_http_info(section_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str section_gid: The globally unique identifier for the section. (required)
        :param SectionGidAddTaskBody body: The task and optionally the insert location.
        :return: EmptyResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['section_gid', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_task_for_section" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'section_gid' is set
        if ('section_gid' not in params or
                params['section_gid'] is None):
            raise ValueError("Missing the required parameter `section_gid` when calling `add_task_for_section`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'section_gid' in params:
            path_params['section_gid'] = params['section_gid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/sections/{section_gid}/addTask', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_section_for_project(self, project_gid, **kwargs):  # noqa: E501
        """Create a section in a project  # noqa: E501

        Creates a new section in a project. Returns the full record of the newly created section.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_section_for_project(project_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_gid: Globally unique identifier for the project. (required)
        :param ProjectGidSectionsBody body: The section to create.
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: SectionResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_section_for_project_with_http_info(project_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.create_section_for_project_with_http_info(project_gid, **kwargs)  # noqa: E501
            return data

    def create_section_for_project_with_http_info(self, project_gid, **kwargs):  # noqa: E501
        """Create a section in a project  # noqa: E501

        Creates a new section in a project. Returns the full record of the newly created section.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_section_for_project_with_http_info(project_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_gid: Globally unique identifier for the project. (required)
        :param ProjectGidSectionsBody body: The section to create.
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: SectionResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_gid', 'body', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_section_for_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_gid' is set
        if ('project_gid' not in params or
                params['project_gid'] is None):
            raise ValueError("Missing the required parameter `project_gid` when calling `create_section_for_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_gid' in params:
            path_params['project_gid'] = params['project_gid']  # noqa: E501

        query_params = []
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_gid}/sections', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SectionResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_section(self, section_gid, **kwargs):  # noqa: E501
        """Delete a section  # noqa: E501

        A specific, existing section can be deleted by making a DELETE request on the URL for that section.  Note that sections must be empty to be deleted.  The last remaining section cannot be deleted.  Returns an empty data block.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_section(section_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str section_gid: The globally unique identifier for the section. (required)
        :return: EmptyResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_section_with_http_info(section_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_section_with_http_info(section_gid, **kwargs)  # noqa: E501
            return data

    def delete_section_with_http_info(self, section_gid, **kwargs):  # noqa: E501
        """Delete a section  # noqa: E501

        A specific, existing section can be deleted by making a DELETE request on the URL for that section.  Note that sections must be empty to be deleted.  The last remaining section cannot be deleted.  Returns an empty data block.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_section_with_http_info(section_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str section_gid: The globally unique identifier for the section. (required)
        :return: EmptyResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['section_gid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_section" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'section_gid' is set
        if ('section_gid' not in params or
                params['section_gid'] is None):
            raise ValueError("Missing the required parameter `section_gid` when calling `delete_section`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'section_gid' in params:
            path_params['section_gid'] = params['section_gid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/sections/{section_gid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_section(self, section_gid, **kwargs):  # noqa: E501
        """Get a section  # noqa: E501

        Returns the complete record for a single section.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_section(section_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str section_gid: The globally unique identifier for the section. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: SectionResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_section_with_http_info(section_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_section_with_http_info(section_gid, **kwargs)  # noqa: E501
            return data

    def get_section_with_http_info(self, section_gid, **kwargs):  # noqa: E501
        """Get a section  # noqa: E501

        Returns the complete record for a single section.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_section_with_http_info(section_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str section_gid: The globally unique identifier for the section. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: SectionResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['section_gid', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_section" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'section_gid' is set
        if ('section_gid' not in params or
                params['section_gid'] is None):
            raise ValueError("Missing the required parameter `section_gid` when calling `get_section`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'section_gid' in params:
            path_params['section_gid'] = params['section_gid']  # noqa: E501

        query_params = []
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/sections/{section_gid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SectionResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sections_for_project(self, project_gid, **kwargs):  # noqa: E501
        """Get sections in a project  # noqa: E501

        Returns the compact records for all sections in the specified project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sections_for_project(project_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_gid: Globally unique identifier for the project. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: SectionResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sections_for_project_with_http_info(project_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sections_for_project_with_http_info(project_gid, **kwargs)  # noqa: E501
            return data

    def get_sections_for_project_with_http_info(self, project_gid, **kwargs):  # noqa: E501
        """Get sections in a project  # noqa: E501

        Returns the compact records for all sections in the specified project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sections_for_project_with_http_info(project_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_gid: Globally unique identifier for the project. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: SectionResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_gid', 'limit', 'offset', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sections_for_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_gid' is set
        if ('project_gid' not in params or
                params['project_gid'] is None):
            raise ValueError("Missing the required parameter `project_gid` when calling `get_sections_for_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_gid' in params:
            path_params['project_gid'] = params['project_gid']  # noqa: E501

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_gid}/sections', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SectionResponseArray',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def insert_section_for_project(self, project_gid, **kwargs):  # noqa: E501
        """Move or Insert sections  # noqa: E501

        Move sections relative to each other. One of `before_section` or `after_section` is required.  Sections cannot be moved between projects.  Returns an empty data block.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.insert_section_for_project(project_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_gid: Globally unique identifier for the project. (required)
        :param SectionsInsertBody body: The section's move action.
        :return: EmptyResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.insert_section_for_project_with_http_info(project_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.insert_section_for_project_with_http_info(project_gid, **kwargs)  # noqa: E501
            return data

    def insert_section_for_project_with_http_info(self, project_gid, **kwargs):  # noqa: E501
        """Move or Insert sections  # noqa: E501

        Move sections relative to each other. One of `before_section` or `after_section` is required.  Sections cannot be moved between projects.  Returns an empty data block.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.insert_section_for_project_with_http_info(project_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_gid: Globally unique identifier for the project. (required)
        :param SectionsInsertBody body: The section's move action.
        :return: EmptyResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_gid', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method insert_section_for_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_gid' is set
        if ('project_gid' not in params or
                params['project_gid'] is None):
            raise ValueError("Missing the required parameter `project_gid` when calling `insert_section_for_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_gid' in params:
            path_params['project_gid'] = params['project_gid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_gid}/sections/insert', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_section(self, section_gid, **kwargs):  # noqa: E501
        """Update a section  # noqa: E501

        A specific, existing section can be updated by making a PUT request on the URL for that project. Only the fields provided in the `data` block will be updated; any unspecified fields will remain unchanged. (note that at this time, the only field that can be updated is the `name` field.)  When using this method, it is best to specify only those fields you wish to change, or else you may overwrite changes made by another user since you last retrieved the task.  Returns the complete updated section record.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_section(section_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str section_gid: The globally unique identifier for the section. (required)
        :param SectionsSectionGidBody body: The section to create.
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: SectionResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_section_with_http_info(section_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.update_section_with_http_info(section_gid, **kwargs)  # noqa: E501
            return data

    def update_section_with_http_info(self, section_gid, **kwargs):  # noqa: E501
        """Update a section  # noqa: E501

        A specific, existing section can be updated by making a PUT request on the URL for that project. Only the fields provided in the `data` block will be updated; any unspecified fields will remain unchanged. (note that at this time, the only field that can be updated is the `name` field.)  When using this method, it is best to specify only those fields you wish to change, or else you may overwrite changes made by another user since you last retrieved the task.  Returns the complete updated section record.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_section_with_http_info(section_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str section_gid: The globally unique identifier for the section. (required)
        :param SectionsSectionGidBody body: The section to create.
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: SectionResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['section_gid', 'body', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_section" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'section_gid' is set
        if ('section_gid' not in params or
                params['section_gid'] is None):
            raise ValueError("Missing the required parameter `section_gid` when calling `update_section`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'section_gid' in params:
            path_params['section_gid'] = params['section_gid']  # noqa: E501

        query_params = []
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/sections/{section_gid}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SectionResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BatchRequestActions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'relative_path': 'str',
        'method': 'str',
        'data': 'object',
        'options': 'BatchRequestOptions'
    }

    attribute_map = {
        'relative_path': 'relative_path',
        'method': 'method',
        'data': 'data',
        'options': 'options'
    }

    def __init__(self, relative_path=None, method=None, data=None, options=None):  # noqa: E501
        """BatchRequestActions - a model defined in Swagger"""  # noqa: E501
        self._relative_path = None
        self._method = None
        self._data = None
        self._options = None
        self.discriminator = None
        self.relative_path = relative_path
        self.method = method
        if data is not None:
            self.data = data
        if options is not None:
            self.options = options

    @property
    def relative_path(self):
        """Gets the relative_path of this BatchRequestActions.  # noqa: E501

        The path of the desired endpoint relative to the API’s base URL. Query parameters are not accepted here; put them in `data` instead.  # noqa: E501

        :return: The relative_path of this BatchRequestActions.  # noqa: E501
        :rtype: str
        """
        return self._relative_path

    @relative_path.setter
    def relative_path(self, relative_path):
        """Sets the relative_path of this BatchRequestActions.

        The path of the desired endpoint relative to the API’s base URL. Query parameters are not accepted here; put them in `data` instead.  # noqa: E501

        :param relative_path: The relative_path of this BatchRequestActions.  # noqa: E501
        :type: str
        """
        if relative_path is None:
            raise ValueError("Invalid value for `relative_path`, must not be `None`")  # noqa: E501

        self._relative_path = relative_path

    @property
    def method(self):
        """Gets the method of this BatchRequestActions.  # noqa: E501

        The HTTP method you wish to emulate for the action.  # noqa: E501

        :return: The method of this BatchRequestActions.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this BatchRequestActions.

        The HTTP method you wish to emulate for the action.  # noqa: E501

        :param method: The method of this BatchRequestActions.  # noqa: E501
        :type: str
        """
        if method is None:
            raise ValueError("Invalid value for `method`, must not be `None`")  # noqa: E501
        allowed_values = ["get", "post", "put", "delete", "patch", "head"]  # noqa: E501
        if method not in allowed_values:
            raise ValueError(
                "Invalid value for `method` ({0}), must be one of {1}"  # noqa: E501
                .format(method, allowed_values)
            )

        self._method = method

    @property
    def data(self):
        """Gets the data of this BatchRequestActions.  # noqa: E501

        For `GET` requests, this should be a map of query parameters you would have normally passed in the URL. Options and pagination are not accepted here; put them in `options` instead. For `POST`, `PATCH`, and `PUT` methods, this should be the content you would have normally put in the data field of the body.  # noqa: E501

        :return: The data of this BatchRequestActions.  # noqa: E501
        :rtype: object
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this BatchRequestActions.

        For `GET` requests, this should be a map of query parameters you would have normally passed in the URL. Options and pagination are not accepted here; put them in `options` instead. For `POST`, `PATCH`, and `PUT` methods, this should be the content you would have normally put in the data field of the body.  # noqa: E501

        :param data: The data of this BatchRequestActions.  # noqa: E501
        :type: object
        """

        self._data = data

    @property
    def options(self):
        """Gets the options of this BatchRequestActions.  # noqa: E501


        :return: The options of this BatchRequestActions.  # noqa: E501
        :rtype: BatchRequestOptions
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this BatchRequestActions.


        :param options: The options of this BatchRequestActions.  # noqa: E501
        :type: BatchRequestOptions
        """

        self._options = options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BatchRequestActions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchRequestActions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
